Welcome to phyid's documentation!
---------------------------------

.. include:: ../README.rst

Contents
--------

.. toctree::
   :maxdepth: 2

   api



Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
